@@ -1,18 +1,28 @@
 DEBIAN_REVISION = ""
-UPSTREAM_VERSION = "13.10+bzr73"
+UPSTREAM_VERSION = "14.12"
 VERSION = "%s%s" % (UPSTREAM_VERSION, DEBIAN_REVISION)
 
-# The "server-api" field of outgoing messages will be set to this value, and
-# used by the server message system to lookup the correct MessageAPI adapter
-# for handling the messages sent by the client. Bump it when the schema of any
-# of the messages sent by the client changes in a backward-incompatible way.
+# The minimum server API version that all Landscape servers are known to speak
+# and support. It can serve as fallback in case higher versions are not there.
+DEFAULT_SERVER_API = "3.2"
+
+# The highest server API version that the client is capable of speaking. The
+# client will use it, unless the server declares to support only a lower
+# version. In that case the server's version will be used. The client will set
+# the X-Message-API HTTP header and the "server-api" payload field of outgoing
+# requests to this value, and the server message system will use it to lookup
+# the correct MessageAPI adapter for handling the messages sent by the client.
+# Bump it when the schema of any of the messages sent by the client changes in
+# a backward-incompatible way.
 #
 # Changelog:
 #
+# 3.3:
+#  * Add new schema for the "registration" message, providing Juju information
 # 3.2:
 #  * Add new "eucalyptus-info" and "eucalyptus-info-error" messages.
 #
-SERVER_API = "3.2"
+SERVER_API = "3.3"
 
 # XXX This is needed for backward compatibility in the server code importing
 # the API variable. We should eventually replace it in the server code.
