@@ -1,7 +1,7 @@
-from landscape import SERVER_API, CLIENT_API
+from landscape import CLIENT_API
 from landscape.lib.persist import Persist
+from landscape.lib.fetch import HTTPCodeError
 from landscape.lib.hashlib import md5
-from landscape.lib.fetch import fetch_async
 from landscape.schema import Message, Int
 from landscape.broker.config import BrokerConfiguration
 from landscape.broker.exchange import get_accepted_types_diff, MessageExchange
@@ -15,15 +15,6 @@ from landscape.broker.tests.helpers import ExchangeHelper
 from landscape.broker.server import BrokerServer
 
 
-class RaisingTransport(object):
-
-    def get_url(self2):
-        return ""
-
-    def exchange(self2, *args):
-        raise RuntimeError("Failed to communicate.")
-
-
 class MessageExchangeTest(LandscapeTest):
 
     helpers = [ExchangeHelper]
@@ -112,7 +103,7 @@ class MessageExchangeTest(LandscapeTest):
         messages = self.transport.payloads[0]["messages"]
         self.assertEqual(messages, [{"type": "empty",
                                      "timestamp": 0,
-                                     "api": SERVER_API}])
+                                     "api": "3.2"}])
 
     def test_send_urgent(self):
         """
@@ -529,18 +520,14 @@ class MessageExchangeTest(LandscapeTest):
         payload = self.transport.payloads[-1]
         self.assertMessages(payload["messages"], [])
         self.assertEqual(payload.get("client-api"), CLIENT_API)
-        self.assertEqual(payload.get("server-api"), SERVER_API)
-        self.assertEqual(self.transport.message_api, SERVER_API)
+        self.assertEqual(payload.get("server-api"), "3.2")
+        self.assertEqual(self.transport.message_api, "3.2")
 
         self.mstore.add({"type": "a", "api": "1.0"})
         self.mstore.add({"type": "b", "api": "1.0"})
         self.mstore.add({"type": "c", "api": "1.1"})
         self.mstore.add({"type": "d", "api": "1.1"})
 
-        # Simulate an old 2.0 client, which has no API on messages.
-        self.mstore.add({"type": "e", "api": None})
-        self.mstore.add({"type": "f", "api": None})
-
         self.exchanger.exchange()
 
         payload = self.transport.payloads[-1]
@@ -561,16 +548,6 @@ class MessageExchangeTest(LandscapeTest):
         self.assertEqual(payload.get("server-api"), "1.1")
         self.assertEqual(self.transport.message_api, "1.1")
 
-        self.exchanger.exchange()
-
-        payload = self.transport.payloads[-1]
-        self.assertMessages(payload["messages"],
-                            [{"type": "e", "api": None},
-                             {"type": "f", "api": None}])
-        self.assertEqual(payload.get("client-api"), CLIENT_API)
-        self.assertEqual(payload.get("server-api"), "2.0")
-        self.assertEqual(self.transport.message_api, "2.0")
-
     def test_exchange_token(self):
         """
         When sending messages to the server, the exchanger provides the
@@ -840,6 +817,35 @@ class MessageExchangeTest(LandscapeTest):
         self.exchanger.exchange()
         self.assertEqual(messages, [("one", msg), ("two", msg)])
 
+    def test_server_api_with_old_server(self):
+        """
+        If a server doesn't indicate which is its highest server-api, it
+        will be 3.2 for sure.
+        """
+        self.transport.extra.pop("server-api", None)
+        self.exchanger.exchange()
+        self.assertEqual("3.2", self.mstore.get_server_api())
+
+    def test_wb_client_with_older_api_and_server_with_newer(self):
+        """
+        If a server notifies us that it case use a very new API, but we
+        don't know how to speak it, we keep using ours.
+        """
+        self.exchanger._api = "3.3"
+        self.transport.extra["server-api"] = "3.4"
+        self.exchanger.exchange()
+        self.assertEqual("3.3", self.mstore.get_server_api())
+
+    def test_wb_client_with_newer_api_and_server_with_older(self):
+        """
+        If a server notifies us that it can use an API which is older
+        than the one we support, we'll just use the server API.
+        """
+        self.exchanger._api = "3.4"
+        self.transport.extra["server-api"] = "3.3"
+        self.exchanger.exchange()
+        self.assertEqual("3.3", self.mstore.get_server_api())
+
     def test_server_uuid_is_stored_on_message_store(self):
         self.transport.extra["server-uuid"] = "first-uuid"
         self.exchanger.exchange()
@@ -991,24 +997,19 @@ class MessageExchangeTest(LandscapeTest):
             events.append(None)
 
         self.reactor.call_on("exchange-failed", failed_exchange)
-        self.exchanger._transport = RaisingTransport()
+        self.transport.responses.append(RuntimeError("Failed to communicate."))
         self.exchanger.exchange()
         self.assertEqual([None], events)
 
-    def test_error_exchanging_records_failure_in_message_store(self):
+    def test_wb_error_exchanging_records_failure_in_message_store(self):
         """
         If a traceback occurs whilst exchanging, the failure is recorded
         in the message store.
         """
-        mock_message_store = self.mocker.proxy(self.mstore)
-        mock_message_store.record_failure(MATCH(lambda x: type(x) is int))
-        self.mocker.result(None)
-        self.mocker.replay()
-
-        exchanger = MessageExchange(
-            self.reactor, mock_message_store, RaisingTransport(),
-            self.identity, self.exchange_store, self.config)
-        exchanger.exchange()
+        self.reactor.advance(123)
+        self.transport.responses.append(RuntimeError("Failed to communicate."))
+        self.exchanger.exchange()
+        self.assertEqual(123, self.mstore._persist.get("first-failure-time"))
 
     def test_error_exchanging_marks_exchange_complete(self):
         """
@@ -1021,7 +1022,7 @@ class MessageExchangeTest(LandscapeTest):
             events.append(None)
 
         self.reactor.call_on("exchange-done", exchange_done)
-        self.exchanger._transport = RaisingTransport()
+        self.transport.responses.append(RuntimeError("Failed to communicate."))
         self.exchanger.exchange()
         self.assertEqual([None], events)
 
@@ -1029,10 +1030,19 @@ class MessageExchangeTest(LandscapeTest):
         """
         If a traceback occurs whilst exchanging, the failure is logged.
         """
-        self.exchanger._transport = RaisingTransport()
+        self.transport.responses.append(RuntimeError("Failed to communicate."))
         self.exchanger.exchange()
         self.assertIn("Message exchange failed.", self.logfile.getvalue())
 
+    def test_exchange_error_with_404_downgrades_server_api(self):
+        """
+        If we get a 404, we try to donwgrade our server API version.
+        """
+        self.mstore.set_server_api("3.3")
+        self.transport.responses.append(HTTPCodeError(404, ""))
+        self.exchanger.exchange()
+        self.assertEqual("3.2", self.mstore.get_server_api())
+
 
 class AcceptedTypesMessageExchangeTest(LandscapeTest):
 
@@ -1046,7 +1056,7 @@ class AcceptedTypesMessageExchangeTest(LandscapeTest):
         # message types that we want to catch as well
         self.handler = RegistrationHandler(
             self.config, self.identity, self.reactor, self.exchanger,
-            self.pinger, self.mstore, fetch_async)
+            self.pinger, self.mstore)
 
     def test_register_accepted_message_type(self):
         self.exchanger.register_client_accepted_message_type("type-B")
