@@ -8,7 +8,6 @@ from landscape.schema import InvalidError, Message, Int, Bytes, Unicode
 
 from landscape.tests.helpers import LandscapeTest
 from landscape.tests.mocker import ANY
-from landscape import SERVER_API
 
 
 class MessageStoreTest(LandscapeTest):
@@ -133,7 +132,7 @@ class MessageStoreTest(LandscapeTest):
         self.assertMessages(messages,
                             [{"type": "data",
                               "data": "A thing",
-                              "api": SERVER_API}])
+                              "api": "3.2"}])
 
     def test_max_pending(self):
         for i in range(10):
@@ -271,7 +270,7 @@ class MessageStoreTest(LandscapeTest):
         messages = self.store.get_pending_messages()
 
         self.assertEqual(messages, [{"type": "data", "data": "2",
-                                     "api": SERVER_API}])
+                                     "api": "3.2"}])
 
         self.store.set_pending_offset(len(messages))
 
@@ -302,29 +301,44 @@ class MessageStoreTest(LandscapeTest):
         self.mocker.verify()
         self.mocker.reset()
         self.assertEqual(self.store.get_pending_messages(),
-                         [{"type": "data", "data": 1, "api": SERVER_API}])
+                         [{"type": "data", "data": 1, "api": "3.2"}])
 
-    def test_api_attribute(self):
-        self.assertEqual(self.store.api, SERVER_API)
-        new_api = "New API version!"
-        self.store.api = new_api
-        self.assertEqual(self.store.api, new_api)
+    def test_get_server_api_default(self):
+        """
+        By default the initial server API version is 3.2.
+        """
+        self.assertEqual("3.2", self.store.get_server_api())
+
+    def test_set_server_api(self):
+        """
+        It's possible to change the server API version.
+        """
+        self.store.set_server_api("3.3")
+        self.assertEqual("3.3", self.store.get_server_api())
 
     def test_default_api_on_messages(self):
+        """
+        By default messages are tagged with the 3.2 server API.
+        """
         self.store.add({"type": "empty"})
         self.assertEqual(self.store.get_pending_messages(),
-                         [{"type": "empty", "api": SERVER_API}])
+                         [{"type": "empty", "api": "3.2"}])
 
     def test_custom_api_on_store(self):
-        self.store.api = "X.Y"
+        """
+        It's possible to change the server API version attached to outgoing
+        messages.
+        """
+        self.store.set_server_api("3.3")
         self.store.add({"type": "empty"})
         self.assertEqual(self.store.get_pending_messages(),
-                         [{"type": "empty", "api": "X.Y"}])
+                         [{"type": "empty", "api": "3.3"}])
 
     def test_custom_api_on_messages(self):
-        self.store.add({"type": "empty", "api": "X.Y"})
+        self.store.set_server_api("3.3")
+        self.store.add({"type": "empty", "api": "3.2"})
         self.assertEqual(self.store.get_pending_messages(),
-                         [{"type": "empty", "api": "X.Y"}])
+                         [{"type": "empty", "api": "3.2"}])
 
     def test_coercion(self):
         """
@@ -350,11 +364,42 @@ class MessageStoreTest(LandscapeTest):
         self.store.add_schema(Message("data", {"data": Unicode()}))
         self.store.add({"type": "data",
                         "data": u"\N{HIRAGANA LETTER A}".encode("utf-8"),
-                        "api": "whatever"})
+                        "api": "3.2"})
         self.assertEqual(self.store.get_pending_messages(),
-                         [{"type": "data", "api": "whatever",
+                         [{"type": "data", "api": "3.2",
                            "data": u"\N{HIRAGANA LETTER A}"}])
 
+    def test_message_is_coerced_to_its_api_schema(self):
+        """
+        A message gets coerced to the schema of the API its targeted to.
+        """
+        self.store.set_server_api("3.3")
+        # Add a new schema for the 'data' message type, with a slightly
+        # different definition.
+        self.store.add_schema(Message("data", {"data": Int()}, api="3.3"))
+
+        # The message is coerced against the new schema.
+        self.store.add({"type": "data", "data": 123})
+        self.assertEqual(
+            self.store.get_pending_messages(),
+            [{"type": "data", "api": "3.3", "data": 123}])
+
+    def test_message_is_coerced_to_highest_compatible_api_schema(self):
+        """
+        A message gets coerced to the schema of the highest compatible
+        API version.
+        """
+        # Add a new schema for the 'data' message type, with a slightly
+        # different definition.
+        self.store.set_server_api("3.2")
+        self.store.add_schema(Message("data", {"data": Int()}, api="3.3"))
+
+        # The message is coerced against the older schema.
+        self.store.add({"type": "data", "data": "foo"})
+        self.assertEqual(
+            self.store.get_pending_messages(),
+            [{"type": "data", "api": "3.2", "data": "foo"}])
+
     def test_count_pending_messages(self):
         """It is possible to get the total number of pending messages."""
         self.assertEqual(self.store.count_pending_messages(), 0)
