@@ -48,9 +48,7 @@ class ManagerServiceTest(LandscapeTest):
             [connector] = self.broker_service.broker.get_connectors()
             connector.disconnect()
             self.service.stopService()
-            self.service.port.stopListening()
             self.broker_service.stopService()
-            self.broker_service.port.stopListening()
 
         def assert_broker_connection(ignored):
             self.assertEqual(len(self.broker_service.broker.get_clients()), 1)
