@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import os
 
 from landscape.lib.persist import Persist
@@ -84,6 +85,83 @@ class UserOperationsMessagingTest(UserGroupTestBase):
         result.addCallback(handle_callback)
         return result
 
+    def test_add_user_event_utf8(self):
+        """
+        When an C{add-user} event with utf-8 unicode strings is received the
+        user should be added.
+        """
+        def handle_callback(result):
+            messages = self.broker_service.message_store.get_pending_messages()
+            self.assertMessages(messages,
+                                [{"type": "operation-result",
+                                  "status": SUCCEEDED,
+                                  "operation-id": 123, "timestamp": 0,
+                                  "result-text": "add_user succeeded"},
+                                  {"timestamp": 0, "type": "users",
+                                  "operation-id": 123,
+                                  "create-users": [{"home-phone": None,
+                                                    "username": "jdoe",
+                                                    "uid": 1000,
+                                                    "enabled": True,
+                                                    "location": "Room 101",
+                                                    "work-phone": "+12345",
+                                                    "name": u"請不要刪除",
+                                                    "primary-gid": 1000}]}])
+
+        self.setup_environment([], [], None)
+
+        result = self.manager.dispatch_message(
+            {"username": "jdoe", "name": "請不要刪除", "password": "password",
+             "operation-id": 123, "require-password-reset": False,
+             "primary-group-name": None, "location": "Room 101",
+             "work-number": "+12345", "home-number": None,
+             "type": "add-user"})
+
+        result.addCallback(handle_callback)
+        return result
+
+    def test_add_user_event_utf8_wire_data(self):
+        """
+        When an C{add-user} event with utf-8 decoded unicode string is
+        received the user should be added. This is what the server is
+        sending over the wire in the real-world.
+        """
+        def handle_callback(result):
+            messages = self.broker_service.message_store.get_pending_messages()
+            self.assertMessages(messages,
+                                [{"type": "operation-result",
+                                  "status": SUCCEEDED,
+                                  "operation-id": 123, "timestamp": 0,
+                                  "result-text": "add_user succeeded"},
+                                  {"timestamp": 0, "type": "users",
+                                  "operation-id": 123,
+                                  "create-users": [
+                                      {"home-phone": u"請不要刪除",
+                                       "username": u"請不要刪除",
+                                       "uid": 1000,
+                                       "enabled": True,
+                                       "location": u"請不要刪除",
+                                       "work-phone": u"請不要刪除",
+                                       "name": u"請不要刪除",
+                                       "primary-gid": 1000}]}])
+
+        self.setup_environment([], [], None)
+
+        result = self.manager.dispatch_message(
+            {'username': u'\u8acb\u4e0d\u8981\u522a\u9664',
+             'work-number': u'\u8acb\u4e0d\u8981\u522a\u9664',
+             'home-number': u'\u8acb\u4e0d\u8981\u522a\u9664',
+             'name': u'\u8acb\u4e0d\u8981\u522a\u9664',
+             'operation-id': 123,
+             'require-password-reset': False,
+             'password': u'\u8acb\u4e0d\u8981\u522a\u9664',
+             'type': 'add-user',
+             'primary-group-name': u'\u8acb\u4e0d\u8981\u522a\u9664',
+             'location': u'\u8acb\u4e0d\u8981\u522a\u9664'})
+
+        result.addCallback(handle_callback)
+        return result
+
     def test_failing_add_user_event(self):
         """
         When an C{add-user} event is received the user should be
@@ -344,7 +422,7 @@ class UserOperationsMessagingTest(UserGroupTestBase):
         def handle_callback(ignored):
             messages = self.broker_service.message_store.get_pending_messages()
             # Ignore the message created by plugin.run.
-            messages = sorted(messages[1:3],
+            messages = sorted([messages[1], messages[3]],
                               key=lambda message: message["operation-id"])
             self.assertMessages(messages,
                                 [{"type": "operation-result",
