@@ -5,8 +5,8 @@ ALL_PLUGINS = ["ActiveProcessInfo", "ComputerInfo",
                "LoadAverage", "MemoryInfo", "MountInfo", "ProcessorInfo",
                "Temperature", "PackageMonitor", "UserMonitor",
                "RebootRequired", "AptPreferences", "NetworkActivity",
-               "NetworkDevice", "UpdateManager", "CPUUsage", "SwiftDeviceInfo",
-               "CephUsage", "JujuInfo"]
+               "NetworkDevice", "UpdateManager", "CPUUsage", "SwiftUsage",
+               "CephUsage"]
 
 
 class MonitorConfiguration(Configuration):
