@@ -20,6 +20,7 @@ class NetworkActivity(MonitorPlugin):
     persist_name = message_type
     run_interval = 30
     _rollover_maxint = 0
+    scope = "network"
 
     max_network_items_to_exchange = 200
 
@@ -60,7 +61,8 @@ class NetworkActivity(MonitorPlugin):
         message = self.create_message()
         if not message:
             return
-        self.registry.broker.send_message(message, urgent=urgent)
+        self.registry.broker.send_message(
+            message, self._session_id, urgent=urgent)
 
     def exchange(self, urgent=False):
         self.registry.broker.call_if_accepted("network-activity",
