@@ -151,7 +151,7 @@ class AptPreferencesTest(LandscapeTest):
         """
         self.mstore.set_accepted_types(["apt-preferences"])
         broker_mock = self.mocker.replace(self.remote)
-        broker_mock.send_message(ANY, urgent=True)
+        broker_mock.send_message(ANY, ANY, urgent=True)
         self.mocker.result(succeed(None))
         self.mocker.replay()
         preferences_filename = os.path.join(self.etc_apt_directory,
@@ -171,7 +171,7 @@ class AptPreferencesTest(LandscapeTest):
         self.makeFile(path=preferences_filename, content="crap")
         self.mstore.set_accepted_types(["apt-preferences"])
         self.plugin.run()
-        self.reactor.fire("resynchronize")
+        self.reactor.fire("resynchronize", scopes=["package"])
         self.plugin.run()
         messages = self.mstore.get_pending_messages()
         self.assertEqual(len(messages), 2)
