@@ -76,28 +76,20 @@ class UserMonitorTest(LandscapeTest):
 
     def test_wb_resynchronize_event(self):
         """
-        When a C{resynchronize} event occurs any cached L{UserChange}
-        snapshots should be cleared and a new message with users generated.
+        When a C{resynchronize} event, with 'users' scope, occurs any cached
+        L{UserChange} snapshots should be cleared and a new message with users
+        generated.
         """
-
-        def resynchronize_complete(result, plugin):
-
-            def resynchronization_new_messages(result):
-                self.assertMessages(
-                    self.broker_service.message_store.get_pending_messages(),
-                    [{"create-group-members": {u"webdev":[u"jdoe"]},
-                      "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                      "create-users": [{"enabled": True, "home-phone": None,
-                                        "location": None, "name": u"JD",
-                                        "primary-gid": 1000, "uid": 1000,
-                                        "username": u"jdoe",
-                                        "work-phone": None}],
-                                        "type": "users"}])
-
-            persist = plugin._persist
-            self.assertTrue(persist.get("users"))
-            self.assertTrue(persist.get("groups"))
-            self.assertMessages(
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.broker_service.message_store.set_accepted_types(["users"])
+        self.monitor.add(self.plugin)
+        self.successResultOf(self.plugin.run())
+        persist = self.plugin._persist
+        self.assertTrue(persist.get("users"))
+        self.assertTrue(persist.get("groups"))
+        self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
                 [{"create-group-members": {u"webdev":[u"jdoe"]},
                   "create-groups": [{"gid": 1000, "name": u"webdev"}],
@@ -106,20 +98,86 @@ class UserMonitorTest(LandscapeTest):
                                     "primary-gid": 1000, "uid": 1000,
                                     "username": u"jdoe", "work-phone": None}],
                                     "type": "users"}])
-            # Clear all the messages from the message store
-            self.broker_service.message_store.delete_all_messages()
-            deferred = self.monitor.reactor.fire("resynchronize")[0]
-            deferred.addCallback(resynchronization_new_messages)
-            return deferred
+        self.broker_service.message_store.delete_all_messages()
+        deferred = self.monitor.reactor.fire(
+            "resynchronize", scopes=["users"])[0]
+        self.successResultOf(deferred)
+        self.assertMessages(
+            self.broker_service.message_store.get_pending_messages(),
+            [{"create-group-members": {u"webdev":[u"jdoe"]},
+              "create-groups": [{"gid": 1000, "name": u"webdev"}],
+              "create-users": [{"enabled": True, "home-phone": None,
+                                "location": None, "name": u"JD",
+                                "primary-gid": 1000, "uid": 1000,
+                                "username": u"jdoe",
+                                "work-phone": None}],
+              "type": "users"}])
 
+    def test_wb_resynchronize_event_with_global_scope(self):
+        """
+        When a C{resynchronize} event, with global scope, occurs we act exactly
+        as if it had 'users' scope.
+        """
         self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
                                 "/home/jdoe", "/bin/sh")]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.add(self.plugin)
-        deferred = self.plugin.run()
-        deferred.addCallback(resynchronize_complete, self.plugin)
-        return deferred
+        self.successResultOf(self.plugin.run())
+        persist = self.plugin._persist
+        self.assertTrue(persist.get("users"))
+        self.assertTrue(persist.get("groups"))
+        self.assertMessages(
+                self.broker_service.message_store.get_pending_messages(),
+                [{"create-group-members": {u"webdev":[u"jdoe"]},
+                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
+                  "create-users": [{"enabled": True, "home-phone": None,
+                                    "location": None, "name": u"JD",
+                                    "primary-gid": 1000, "uid": 1000,
+                                    "username": u"jdoe", "work-phone": None}],
+                                    "type": "users"}])
+        self.broker_service.message_store.delete_all_messages()
+        deferred = self.monitor.reactor.fire("resynchronize")[0]
+        self.successResultOf(deferred)
+        self.assertMessages(
+            self.broker_service.message_store.get_pending_messages(),
+            [{"create-group-members": {u"webdev":[u"jdoe"]},
+              "create-groups": [{"gid": 1000, "name": u"webdev"}],
+              "create-users": [{"enabled": True, "home-phone": None,
+                                "location": None, "name": u"JD",
+                                "primary-gid": 1000, "uid": 1000,
+                                "username": u"jdoe",
+                                "work-phone": None}],
+              "type": "users"}])
+
+    def test_do_not_resynchronize_with_other_scope(self):
+        """
+        When a C{resynchronize} event, with an irrelevant scope, occurs we do
+        nothing.
+        """
+        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
+                                "/home/jdoe", "/bin/sh")]
+        self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
+        self.broker_service.message_store.set_accepted_types(["users"])
+        self.monitor.add(self.plugin)
+        self.successResultOf(self.plugin.run())
+        persist = self.plugin._persist
+        self.assertTrue(persist.get("users"))
+        self.assertTrue(persist.get("groups"))
+        self.assertMessages(
+                self.broker_service.message_store.get_pending_messages(),
+                [{"create-group-members": {u"webdev":[u"jdoe"]},
+                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
+                  "create-users": [{"enabled": True, "home-phone": None,
+                                    "location": None, "name": u"JD",
+                                    "primary-gid": 1000, "uid": 1000,
+                                    "username": u"jdoe", "work-phone": None}],
+                  "type": "users"}])
+        self.broker_service.message_store.delete_all_messages()
+        self.monitor.reactor.fire("resynchronize", scopes=["disk"])[0]
+        self.assertMessages(
+            self.broker_service.message_store.get_pending_messages(),
+            [])
 
     def test_run(self):
         """
@@ -313,7 +371,7 @@ class UserMonitorTest(LandscapeTest):
 
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.broker.send_message = self.mocker.mock()
-        self.monitor.broker.send_message(ANY, urgent=True)
+        self.monitor.broker.send_message(ANY, ANY, urgent=True)
         self.mocker.result(fail(RuntimeError()))
         self.mocker.replay()
 
