@@ -22,7 +22,7 @@ from aptsources.sourceslist import SourcesList
 from apt.progress.text import AcquireProgress
 from apt.progress.base import InstallProgress
 
-from landscape.lib.fs import append_file, create_file, read_file
+from landscape.lib.fs import append_file, create_file, read_file, touch_file
 from landscape.constants import UBUNTU_PATH
 from landscape.package.skeleton import build_skeleton_apt
 
@@ -136,6 +136,7 @@ class AptFacade(object):
         self._pkg2hash = {}
         self._hash2pkg = {}
         self._version_installs = []
+        self._package_installs = set()
         self._global_upgrade = False
         self._version_removals = []
         self._version_hold_creations = []
@@ -143,7 +144,7 @@ class AptFacade(object):
         self.refetch_package_index = False
 
     def _ensure_dir_structure(self):
-        self._ensure_sub_dir("etc/apt")
+        apt_dir = self._ensure_sub_dir("etc/apt")
         self._ensure_sub_dir("etc/apt/sources.list.d")
         self._ensure_sub_dir("var/cache/apt/archives/partial")
         self._ensure_sub_dir("var/lib/apt/lists/partial")
@@ -155,6 +156,9 @@ class AptFacade(object):
         self._dpkg_status = os.path.join(dpkg_dir, "status")
         if not os.path.exists(self._dpkg_status):
             create_file(self._dpkg_status, "")
+        # Apt will fail if it does not have a keyring.  It does not care if
+        # the keyring is empty.
+        touch_file(os.path.join(apt_dir, "trusted.gpg"))
 
     def _ensure_sub_dir(self, sub_dir):
         """Ensure that a dir in the Apt root exists."""
@@ -442,11 +446,30 @@ class AptFacade(object):
             version for version in self.get_packages()
             if version.package.name == name]
 
+    def _is_package_broken(self, package):
+        """Is the package broken?
+
+        It's considered broken if it's one that we marked for install,
+        but it's not marked for install, upgrade or downgrade
+        anymore.
+
+        Before Trusty, checking is_inst_broken was enough, but
+        in Trusty the behaviour changed, so the package simply gets
+        unmarked for installation.
+        """
+        if package.is_inst_broken:
+            return True
+        if (not package.marked_install
+                and not package.marked_upgrade
+                and not package.marked_downgrade):
+            return package in self._package_installs
+        return False
+
     def _get_broken_packages(self):
         """Return the packages that are in a broken state."""
         return set(
             version.package for version in self.get_packages()
-            if version.package.is_inst_broken)
+            if self._is_package_broken(version.package))
 
     def _get_changed_versions(self, package):
         """Return the versions that will be changed for the package.
@@ -674,12 +697,17 @@ class AptFacade(object):
 
     def _preprocess_installs(self, fixer):
         for version in self._version_installs:
+            if version == version.package.installed:
+                # No point in marking it for installation if the
+                # requested version is already installed.
+                continue
             # Set the candidate version, so that the version we want to
             # install actually is the one getting installed.
             version.package.candidate = version
             # Set auto_fix=False to avoid removing the package we asked to
             # install when we need to resolve dependencies.
             version.package.mark_install(auto_fix=False)
+            self._package_installs.add(version.package)
             fixer.clear(version.package._pkg)
             fixer.protect(version.package._pkg)
 
@@ -729,6 +757,10 @@ class AptFacade(object):
             except SystemError, error:
                 raise TransactionError(error.args[0] + "\n" +
                                        self._get_unmet_dependency_info())
+            else:
+                now_broken_packages = self._get_broken_packages()
+                if now_broken_packages != already_broken_packages:
+                    raise TransactionError(self._get_unmet_dependency_info())
 
     def _preprocess_package_changes(self):
         version_changes = self._version_installs[:]
@@ -770,6 +802,7 @@ class AptFacade(object):
     def reset_marks(self):
         """Clear the pending package operations."""
         del self._version_installs[:]
+        self._package_installs.clear()
         del self._version_removals[:]
         del self._version_hold_removals[:]
         del self._version_hold_creations[:]
