@@ -19,17 +19,16 @@ class InvalidHashIdDb(Exception):
 
 
 class HashIdStore(object):
-    """Persist package hash=>id mappings in a file.
+    """C{HashIdStore} stores package hash=>id mappings in a file.
 
-    The implementation uses a SQLite database as backend, with a single
-    table called "hash", whose schema is defined in L{ensure_hash_id_schema}.
+    The file is a SQLite database that contains a single table called "hash".
+    The table schema is defined in L{ensure_hash_id_schema}.
+
+    @param filename: The file where the mappings are persisted to.
     """
     _db = None
 
     def __init__(self, filename):
-        """
-        @param filename: The file where the mappings are persisted to.
-        """
         self._filename = filename
 
     def _ensure_schema(self):
@@ -97,12 +96,11 @@ class PackageStore(HashIdStore):
     about the tasks to be performed by L{PackageTaskHandler}s.
 
     The additional tables and schemas are defined in L{ensure_package_schema}.
+
+    @param filename: The file where data is persisted to.
     """
 
     def __init__(self, filename):
-        """
-        @param filename: The file where data is persisted to.
-        """
         super(PackageStore, self).__init__(filename)
         self._hash_id_stores = []
 
@@ -250,40 +248,6 @@ class PackageStore(HashIdStore):
         """Remove all the package ids in the locked table."""
         cursor.execute("DELETE FROM locked")
 
-    @with_cursor
-    def get_package_locks(self, cursor):
-        """Get all package locks."""
-        cursor.execute("SELECT name, relation, version FROM package_locks")
-        return [(row[0], row[1], row[2]) for row in cursor.fetchall()]
-
-    @with_cursor
-    def add_package_locks(self, cursor, locks):
-        """Add a list of package locks to the store.
-
-        @param locks: A C{list} of ternary tuples each one contains the
-            name, the relation and the version of the package lock to be added.
-        """
-        for name, relation, version in locks:
-            cursor.execute("REPLACE INTO package_locks VALUES (?, ?, ?)",
-                           (name, relation or "", version or "",))
-
-    @with_cursor
-    def remove_package_locks(self, cursor, locks):
-        """Remove a list of package locks from the store.
-
-        @param locks: A C{list} of ternary tuples each one contains the name,
-            the relation and the version of the package lock to be removed.
-        """
-        for name, relation, version in locks:
-            cursor.execute("DELETE FROM package_locks WHERE name=? AND "
-                           "relation=? AND version=?",
-                           (name, relation or "", version or ""))
-
-    @with_cursor
-    def clear_package_locks(self, cursor):
-        """Remove all package locks."""
-        cursor.execute("DELETE FROM package_locks")
-
     @with_cursor
     def add_hash_id_request(self, cursor, hashes):
         hashes = list(hashes)
@@ -331,6 +295,40 @@ class PackageStore(HashIdStore):
                        ",".join([str(task.id) for task in except_tasks]))
 
 
+class FakePackageStore(PackageStore):
+    """
+    A L{PackageStore} with an additional message table to store sent messages.
+    """
+
+    def _ensure_schema(self):
+        super(FakePackageStore, self)._ensure_schema()
+        ensure_fake_package_schema(self._db)
+
+    @with_cursor
+    def save_message(self, cursor, message):
+        cursor.execute("INSERT INTO message (data) VALUES (?)",
+                       (buffer(bpickle.dumps(message)),))
+
+    @with_cursor
+    def get_message_ids(self, cursor):
+        return [row[0] for row in
+                cursor.execute("SELECT id FROM message").fetchall()]
+
+    @with_cursor
+    def save_message_ids(self, cursor, message_ids):
+        cursor.executemany(
+            "INSERT INTO message (id) VALUES (?)",
+            [(message_id,) for message_id in message_ids])
+
+    @with_cursor
+    def get_messages_by_ids(self, cursor, message_ids):
+        params = ", ".join(["?"] * len(message_ids))
+        result = cursor.execute(
+                "SELECT id, data FROM message WHERE id IN (%s) "
+                "ORDER BY id" % params, tuple(message_ids)).fetchall()
+        return [(row[0], row[1]) for row in result]
+
+
 class HashIDRequest(object):
 
     def __init__(self, db, id):
@@ -426,9 +424,6 @@ def ensure_package_schema(db):
     #       try block.
     cursor = db.cursor()
     try:
-        cursor.execute("CREATE TABLE package_locks"
-                       " (name TEXT NOT NULL, relation TEXT, version TEXT,"
-                       " UNIQUE(name, relation, version))")
         cursor.execute("CREATE TABLE locked"
                        " (id INTEGER PRIMARY KEY)")
         cursor.execute("CREATE TABLE available"
@@ -449,3 +444,16 @@ def ensure_package_schema(db):
     else:
         cursor.close()
         db.commit()
+
+
+def ensure_fake_package_schema(db):
+    cursor = db.cursor()
+    try:
+        cursor.execute("CREATE TABLE message"
+                       " (id INTEGER PRIMARY KEY, data BLOB)")
+    except (sqlite3.OperationalError, sqlite3.DatabaseError):
+        cursor.close()
+        db.rollback()
+    else:
+        cursor.close()
+        db.commit()
