@@ -15,7 +15,7 @@ from landscape.configuration import (
     register, setup, main, setup_init_script_and_start_client,
     stop_client_and_disable_init_script, ConfigurationError,
     ImportOptionError, store_public_key_data,
-    fetch_base64_ssl_public_certificate, bootstrap_tree)
+    bootstrap_tree)
 from landscape.broker.registration import InvalidCredentialsError
 from landscape.sysvconfig import SysVConfig, ProcessError
 from landscape.tests.helpers import (
@@ -629,8 +629,8 @@ class LandscapeSetupScriptTest(LandscapeTest):
 
     def test_access_group_defined_on_command_line(self):
         """
-        An access group defined on the command line can be verified by the
-        user.
+        When an access group is provided on the command line, do not prompt
+        the user for it.
         """
         raw_input_mock = self.mocker.replace(raw_input, passthrough=False)
         self.expect(raw_input_mock(ANY)).count(0)
@@ -820,9 +820,7 @@ url = https://landscape.canonical.com/message-system
                 "--ping-interval", "30",
                 "--http-proxy", "",
                 "--https-proxy", "",
-                "--otp", "",
-                "--tags", "",
-                "--provisioning-otp", ""]
+                "--tags", ""]
         config = self.get_config(args)
         setup(config)
         self.assertConfigEqual(
@@ -837,12 +835,9 @@ url = https://landscape.canonical.com/message-system
             "https_proxy = \n"
             "url = https://landscape.canonical.com/message-system\n"
             "exchange_interval = 900\n"
-            "otp = \n"
             "ping_interval = 30\n"
             "ping_url = http://landscape.canonical.com/ping\n"
-            "provisioning_otp = \n"
-            "urgent_exchange_interval = 60\n"
-             % config.data_path)
+            "urgent_exchange_interval = 60\n" % config.data_path)
 
     def test_silent_setup_without_computer_title(self):
         """A computer title is required."""
@@ -862,35 +857,6 @@ url = https://landscape.canonical.com/message-system
         config = self.get_config(["--silent", "-t", "rex"])
         self.assertRaises(ConfigurationError, setup, config)
 
-    def test_silent_setup_with_otp(self):
-        """
-        If the OTP is specified, there is no need to pass the account name and
-        the computer title.
-        """
-        sysvconfig_mock = self.mocker.patch(SysVConfig)
-        sysvconfig_mock.set_start_on_boot(True)
-        self.mocker.replay()
-
-        config = self.get_config(["--silent", "--otp", "otp1"])
-        setup(config)
-
-        self.assertEqual("otp1", config.otp)
-
-    def test_silent_setup_with_provisioning_otp(self):
-        """
-        If the provisioning OTP is specified, there is no need to pass the
-        account name and the computer title.
-        """
-        sysvconfig_mock = self.mocker.patch(SysVConfig)
-        sysvconfig_mock.set_start_on_boot(True)
-        sysvconfig_mock.restart_landscape()
-        self.mocker.replay()
-
-        config = self.get_config(["--silent", "--provisioning-otp", "otp1"])
-        setup(config)
-
-        self.assertEqual("otp1", config.provisioning_otp)
-
     def test_silent_script_users_imply_script_execution_plugin(self):
         """
         If C{--script-users} is specified, without C{ScriptExecution} in the
@@ -1719,7 +1685,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         service = self.broker_service
 
         registration_mock = self.mocker.replace(service.registration)
-        config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.patch(FakeReactor)
 
@@ -1733,9 +1698,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         time_mock.sleep(ANY)
         self.mocker.count(1)
 
-        # After a nice dance the configuration is reloaded.
-        config_mock.reload()
-
         # The register() method is called.  We fire the "registration-done"
         # event after it's done, so that it cascades into a deferred callback.
 
@@ -1773,7 +1735,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
 
         self.log_helper.ignore_errors(InvalidCredentialsError)
         registration_mock = self.mocker.replace(service.registration)
-        config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.patch(FakeReactor)
 
@@ -1787,9 +1748,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         time_mock.sleep(ANY)
         self.mocker.count(1)
 
-        # After a nice dance the configuration is reloaded.
-        config_mock.reload()
-
         # The register() method is called.  We fire the "registration-failed"
         # event after it's done, so that it cascades into a deferred errback.
 
@@ -1828,7 +1786,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         service = self.broker_service
 
         registration_mock = self.mocker.replace(service.registration)
-        config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.patch(FakeReactor)
 
@@ -1842,9 +1799,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         time_mock.sleep(ANY)
         self.mocker.count(1)
 
-        # After a nice dance the configuration is reloaded.
-        config_mock.reload()
-
         def register_done():
             service.reactor.fire("exchange-failed")
         registration_mock.register()
@@ -1878,7 +1832,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         service = self.broker_service
 
         registration_mock = self.mocker.replace(service.registration)
-        config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.patch(FakeReactor)
         remote_mock = self.mocker.patch(RemoteBroker)
@@ -1898,9 +1851,6 @@ class RegisterFunctionTest(LandscapeConfigurationTest):
         time_mock.sleep(ANY)
         self.mocker.count(1)
 
-        # After a nice dance the configuration is reloaded.
-        config_mock.reload()
-
         remote_mock.call_on_event(ANY)
         self.mocker.result(succeed(None))
 
@@ -2109,8 +2059,6 @@ class RegisterFunctionNoServiceTest(LandscapeTest):
         connector = connector_factory(ANY, configuration)
         connector.connect(max_retries=0, quiet=True)
         self.mocker.result(succeed(remote_broker))
-        remote_broker.reload_configuration()
-        self.mocker.result(succeed(None))
         remote_broker.call_on_event(ANY)
         self.mocker.result(succeed(None))
 
@@ -2160,84 +2108,3 @@ class SSLCertificateDataTest(LandscapeConfigurationTest):
         self.assertEqual(key_filename,
                          store_public_key_data(config, "123456789"))
         self.assertEqual("123456789", open(key_filename, "r").read())
-
-    def test_fetch_base64_ssl(self):
-        """
-        L{fetch_base64_ssl_public_certificate} should pull a JSON object from
-        http://providedhostname/get-ca-cert. And return the custom_ca_cert data
-        if it exists.
-        """
-        base64_cert = "base64:  MTIzNDU2Nzg5MA=="  # encoded woo hoo
-        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
-        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
-        self.mocker.result(
-            "{\"custom_ca_cert\": \"%s\"}" % base64_cert)
-        self.mocker.replay()
-
-        def check_info(info):
-            self.assertEqual(
-                "Fetching CA certificate from fakehost if available...",
-                str(info))
-
-        content = fetch_base64_ssl_public_certificate("fakehost",
-                                                      on_info=check_info)
-        self.assertEqual(base64_cert, content)
-
-    def test_fetch_base64_ssl_no_custom_ca(self):
-        """
-        L{fetch_base64_ssl_public_certificate} should pull a JSON object from
-        http://providedhostname/get-ca-cert. And return the custom_ca_cert data
-        if it exists, otherwise it should return an empty string.""
-        """
-        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
-        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
-        self.mocker.result("{}")
-
-        print_text_mock = self.mocker.replace(print_text)
-        print_text_mock(
-            "Fetching CA certificate from fakehost if available...")
-        print_text_mock("No custom CA certificate available for fakehost.")
-        self.mocker.replay()
-
-        content = fetch_base64_ssl_public_certificate("fakehost",
-                                                      on_info=print_text)
-        self.assertEqual("", content)
-
-    def test_fetch_base64_ssl_with_http_code_fetch_error(self):
-        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
-        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
-        self.mocker.throw(HTTPCodeError(404, ""))
-        print_text_mock = self.mocker.replace(print_text)
-        print_text_mock(
-            "Fetching CA certificate from fakehost if available...")
-        self.mocker.replay()
-
-        def check_error(error):
-            self.assertEqual("Unable to fetch CA certificate from discovered "
-                             "server fakehost: Server does not support client "
-                             "auto-registation.",
-                             str(error))
-
-        content = fetch_base64_ssl_public_certificate("fakehost",
-                                                      on_info=print_text,
-                                                      on_error=check_error)
-        self.assertEquals("", content)
-
-    def test_fetch_base64_ssl_with_pycurl_error(self):
-        fetch_mock = self.mocker.replace("landscape.lib.fetch.fetch")
-        fetch_mock("http://fakehost/get-ca-cert", insecure=True)
-        self.mocker.throw(PyCurlError(60, "pycurl message"))
-        print_text_mock = self.mocker.replace(print_text)
-        print_text_mock(
-            "Fetching CA certificate from fakehost if available...")
-        self.mocker.replay()
-
-        def check_error(error):
-            self.assertEqual("Unable to fetch CA certificate from fakehost: "
-                             "Error 60: pycurl message",
-                             str(error))
-
-        content = fetch_base64_ssl_public_certificate("fakehost",
-                                                      on_info=print_text,
-                                                      on_error=check_error)
-        self.assertEquals("", content)
