@@ -2,7 +2,7 @@ import thread
 import types
 import time
 
-from landscape.reactor import FakeReactor, TwistedReactor
+from landscape.reactor import FakeReactor, LandscapeReactor
 from landscape.tests.helpers import LandscapeTest
 
 
@@ -115,6 +115,21 @@ class ReactorTestMixin(object):
         reactor.fire("foobar")
         self.assertEqual(called, [True])
 
+    def test_event_multiple_fire(self):
+        """
+        Once an event handler is registered, it's called all times that event
+        type is fired.
+        """
+        reactor = self.get_reactor()
+        called = []
+
+        def handle_foobar():
+            called.append(True)
+        reactor.call_on("foobar", handle_foobar)
+        reactor.fire("foobar")
+        reactor.fire("foobar")
+        self.assertEqual(called, [True, True])
+
     def test_event_with_args(self):
         reactor = self.get_reactor()
         called = []
@@ -243,9 +258,6 @@ class ReactorTestMixin(object):
 
         reactor.call_in_thread(None, None, f, 1, 2, c=3)
 
-        while not called:
-            pass
-
         reactor.call_later(0.7, reactor.stop)
         reactor.run()
 
@@ -274,9 +286,6 @@ class ReactorTestMixin(object):
 
         reactor.call_in_thread(callback, errback, f)
 
-        while not called:
-            pass
-
         reactor.call_later(0.7, reactor.stop)
         reactor.run()
 
@@ -301,9 +310,6 @@ class ReactorTestMixin(object):
 
         reactor.call_in_thread(callback, errback, f)
 
-        while not called:
-            pass
-
         reactor.call_later(0.7, reactor.stop)
         reactor.run()
 
@@ -329,9 +335,6 @@ class ReactorTestMixin(object):
 
         reactor.call_in_thread(callback, None, f)
 
-        while not called:
-            pass
-
         reactor.call_later(0.7, reactor.stop)
         reactor.run()
 
@@ -355,9 +358,6 @@ class ReactorTestMixin(object):
 
         reactor.call_in_thread(None, None, f)
 
-        while not called:
-            pass
-
         reactor.call_later(0.7, reactor.stop)
         reactor.run()
 
@@ -368,6 +368,27 @@ class ReactorTestMixin(object):
         self.assertEqual(called[2], "g")
         self.assertEqual(called[3], thread.get_ident())
 
+    def test_cancelling_handlers(self):
+        """
+        If a handler modifies the list of handlers in-flight, the initial list
+        of handlers is still used (and all handlers are executed).
+        """
+        reactor = self.get_reactor()
+        calls = []
+
+        def handler_1():
+            reactor.cancel_call(event_id)
+
+        def handler_2():
+            calls.append(True)
+
+        # This call cancels itself.
+        event_id = reactor.call_on("foobar", handler_1)
+        reactor.call_on("foobar", handler_2)
+
+        reactor.fire("foobar")
+        self.assertEqual([True], calls)
+
 
 class FakeReactorTest(LandscapeTest, ReactorTestMixin):
 
@@ -402,10 +423,10 @@ class FakeReactorTest(LandscapeTest, ReactorTestMixin):
         self.assertEqual(reactor.time(), 13.5)
 
 
-class TwistedReactorTest(LandscapeTest, ReactorTestMixin):
+class LandscapeReactorTest(LandscapeTest, ReactorTestMixin):
 
     def get_reactor(self):
-        reactor = TwistedReactor()
+        reactor = LandscapeReactor()
         # It's not possible to stop the reactor in a Trial test, calling
         # reactor.crash instead
         saved_stop = reactor._reactor.stop
