@@ -7,4 +7,4 @@ from landscape.upgraders import monitor
 class TestMonitorUpgraders(LandscapeTest):
 
     def test_monitor_upgrade_manager(self):
-        self.assertEquals(type(monitor.upgrade_manager), UpgradeManager)
+        self.assertEqual(type(monitor.upgrade_manager), UpgradeManager)
