@@ -31,9 +31,6 @@ from landscape.log import rotate_logs
 from landscape.broker.amp import (
     RemoteBrokerConnector, RemoteMonitorConnector, RemoteManagerConnector)
 from landscape.reactor import LandscapeReactor
-from landscape.lib.dns import discover_server
-from landscape.configuration import (
-    fetch_base64_ssl_public_certificate, decode_base64_ssl_public_certificate)
 
 GRACEFUL_WAIT_PERIOD = 10
 MAXIMUM_CONSECUTIVE_RESTARTS = 5
@@ -505,45 +502,6 @@ class WatchDogService(Service):
                                  enabled_daemons=config.get_enabled_daemons())
         self.exit_code = 0
 
-    def autodiscover(self):
-        """
-        Autodiscover called if config setting config.server_autodiscover is
-        True. This method allows the watchdog to attempt server autodiscovery,
-        fetch the discovered landscape server's custom CA certificate, and
-        write both the certificate and the updated config file with the
-        discovered values.
-        """
-        def update_config(hostname):
-            if hostname is None:
-                warning("Autodiscovery returned empty hostname string. "
-                        "Reverting to previous settings.")
-            else:
-                info("Autodiscovery found landscape server at %s. "
-                     "Updating configuration values." % hostname)
-                self._config.server_autodiscover = False
-                self._config.url = "https://%s/message-system" % hostname
-                self._config.ping_url = "http://%s/ping" % hostname
-                if not self._config.ssl_public_key:
-                    # If we don't have a key on this system, pull it from
-                    # the auto-discovered server and write it to the filesystem
-                    ssl_public_key = fetch_base64_ssl_public_certificate(
-                        hostname, on_info=info, on_error=warning)
-                    if ssl_public_key:
-                        self._config.ssl_public_key = ssl_public_key
-                        decode_base64_ssl_public_certificate(self._config)
-                self._config.write()
-            return hostname
-
-        def discovery_error(result):
-            warning("Autodiscovery failed.  Reverting to previous settings.")
-
-        lookup_deferred = discover_server(
-            self._config.autodiscover_srv_query_string,
-            self._config.autodiscover_a_query_string)
-        lookup_deferred.addCallback(update_config)
-        lookup_deferred.addErrback(discovery_error)
-        return lookup_deferred
-
     def startService(self):
         Service.startService(self)
         bootstrap_list.bootstrap(data_path=self._config.data_path,
@@ -568,8 +526,6 @@ class WatchDogService(Service):
                     log_dir=self._config.log_dir + suffix)
 
         result = succeed(None)
-        if self._config.server_autodiscover:
-            result.addCallback(lambda _: self.autodiscover())
         result.addCallback(lambda _: self.watchdog.check_running())
 
         def start_if_not_running(running_daemons):
